/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1994, 1995
 * Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the PhaseX 110 keyboard.
 * By Jonathan Abbey <jonabbey@arlut.utexas.edu>, based on the
 * SCO ODT 110 keycodes def by Steven W. Orr <steveo@world.std.com>.
 */

static const KeyCode phasex110_codes [] = {

  /* Row 0 */
  8,
  66, 67, 68, 69,
  70, 71, 72, 73,
  74, 75, 94, 95,
  91, 77, 0,

  /* Row 2 */
  48, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21,
  97, 98, 99,
  76, 103, 62, 81,

  /* Row 3 */
  22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 50,
  100, 101, 102,
  78, 79, 80, 85,
  
  /* Row 4 */
  65, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 35,
  82, 83, 84,

  /* Row 5 */
  49, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61,
  107,
  86, 87, 88, 104,

  /* Row 6 */
  36,
  63, 64, 92,
  96,
  105, 108, 106,
  89, 90
};
